==> rym-util-v1.0.27.tar.gz: rym-util-v1.0.27/redis/RedisClient.go <==
package redis

import (
	"fmt"
	"git.168cad.top/zhengqiuyun/rym-util/conf"
	"git.168cad.top/zhengqiuyun/rym-util/const/YorN"
	"git.168cad.top/zhengqiuyun/rym-util/log"
	"github.com/go-redis/redis"
	"time"
)

func TestLog() {
	log.Info("Redis 测试")
}

var redisClient *redis.Client

func Init() {
	redisClient = redis.NewClient(&redis.Options{
		Addr:     fmt.Sprintf("%s:%d", conf.Redis.RedisHost, conf.Redis.RedisPort),
		Password: conf.Redis.RedisPwd,
		DB:       conf.Redis.RedisDb, // redis一共16个库，指定其中一个库即可
	})
	_, err := redisClient.Ping().Result()
	if err != nil {
		log.Error(fmt.Sprintf("Redis connect error ：%s", err.Error()))
	} else {
		log.Info("Redis connect success")
	}
	return
}

func Incr(key string) int64 {
	r := redisClient.Incr(key)
	return r.Val()
}

func IncrBy(key string, n int64) int64 {
	r := redisClient.IncrBy(key, n)
	return r.Val()
}

func DecrBy(key string, n int64) int64 {
	r := redisClient.DecrBy(key, n)
	return r.Val()
}

func Exists(key string) bool {
	r := redisClient.Exists(key)
	return r.Val() > 0
}

//SwitchOpen 在redis中存0或1,1代表OK
func SwitchOpen(key string) bool {
	r := GetString(key)
	log.Debug(fmt.Sprintf("缓存[%s]数据为：%s", key, r))
	return r == YorN.Y
}

func GetString(key string) string {
	r := redisClient.Get(key)
	return r.Val()
}

func Get(key string) []byte {
	r := redisClient.Get(key)
	rByte, err := r.Bytes()
	if err != nil {
		log.Error(fmt.Sprintf("获取缓存错误：%s", err.Error()))
	}
	return rByte
}

func Set(k string, v string) {
	redisClient.Set(k, v, 0)
	log.Debug(fmt.Sprintf("设置缓存成功：%s %s", k, v))
}

func Expire(k string, t int64) {
	redisClient.Expire(k, time.Duration(t))
	log.Debug(fmt.Sprintf("设置缓存过期成功：%s %d", k, t))
}

==> rym-util-v1.0.28.tar.gz: rym-util-v1.0.28/redis/RedisClient.go <==
package redis

import (
	"fmt"
	"git.168cad.top/zhengqiuyun/rym-util/conf"
	"git.168cad.top/zhengqiuyun/rym-util/const/YorN"
	"git.168cad.top/zhengqiuyun/rym-util/log"
	"github.com/go-redis/redis"
	"time"
)

func TestLog() {
	log.Info("Redis 测试")
}

var redisClient *redis.Client

func Init() {
	redisClient = redis.NewClient(&redis.Options{
		Addr:     fmt.Sprintf("%s:%d", conf.Redis.RedisHost, conf.Redis.RedisPort),
		Password: conf.Redis.RedisPwd,
		DB:       conf.Redis.RedisDb, // redis一共16个库，指定其中一个库即可
	})
	_, err := redisClient.Ping().Result()
	if err != nil {
		log.Error(fmt.Sprintf("Redis connect error ：%s", err.Error()))
	} else {
		log.Info("Redis connect success")
	}
	return
}

func getDb() *redis.Client {
	return redisClient
}

func Incr(key string) int64 {
	r := getDb().Incr(key)
	return r.Val()
}

func IncrBy(key string, n int64) int64 {
	r := getDb().IncrBy(key, n)
	return r.Val()
}

func DecrBy(key string, n int64) int64 {
	r := getDb().DecrBy(key, n)
	return r.Val()
}

func Exists(key string) bool {
	r := getDb().Exists(key)
	return r.Val() > 0
}

//SwitchOpen 在redis中存0或1,1代表OK
func SwitchOpen(key string) bool {
	r := GetString(key)
	log.Debug(fmt.Sprintf("缓存[%s]数据为：%s", key, r))
	return r == YorN.Y
}

func GetString(key string) string {
	r := getDb().Get(key)
	return r.Val()
}

func Get(key string) []byte {
	r := getDb().Get(key)
	rByte, err := r.Bytes()
	if err != nil {
		log.Error(fmt.Sprintf("获取缓存错误：%s", err.Error()))
	}
	return rByte
}

func Set(k string, v string) {
	getDb().Set(k, v, 0)
	log.Debug(fmt.Sprintf("设置缓存成功：%s %s", k, v))
}

func Expire(k string, t int64) {
	getDb().Expire(k, time.Duration(t))
	log.Debug(fmt.Sprintf("设置缓存过期成功：%s %d", k, t))
}
